@@ -96,23 +96,34 @@ if __name__ == "__main__":
                                     amd_smi_commands.monitor,
                                     amd_smi_commands.rocm_smi,
                                     amd_smi_commands.xgmi,
-                                    amd_smi_commands.partition)
+                                    amd_smi_commands.partition,
+                                    amd_smi_commands.ras)
     try:
         try:
             argcomplete.autocomplete(amd_smi_parser)
         except NameError:
             logging.debug("argcomplete module not found. Autocomplete will not work.")
 
+        # Store possible subcommands & aliases for later errors
+        valid_commands = amd_smi_parser.possible_commands
+        valid_commands += ['--help', '-h']
+
         sys.argv = [arg.lower() if arg.startswith('--') or not arg.startswith('-')
                     else arg for arg in sys.argv]
-        args = amd_smi_parser.parse_args(args=None if sys.argv[1:] else ['--help'])
+        if len(sys.argv) == 1:
+            args = amd_smi_parser.parse_args(args=['--help'])
+        elif sys.argv[1] in valid_commands:
+            args = amd_smi_parser.parse_args(args=None)
+        else:
+            raise amdsmi_cli_exceptions.AmdSmiInvalidSubcommandException(sys.argv[1],amd_smi_commands.logger.destination)
 
         # Handle command modifiers before subcommand execution
-        if args.json:
+            # human readable is the default output format
+        if hasattr(args, 'json') and args.json:
             amd_smi_commands.logger.format = amd_smi_commands.logger.LoggerFormat.json.value
-        if args.csv:
+        if hasattr(args, 'csv') and args.csv:
             amd_smi_commands.logger.format = amd_smi_commands.logger.LoggerFormat.csv.value
-        if args.file:
+        if hasattr(args, 'file') and args.file:
             amd_smi_commands.logger.destination = args.file
 
         # Remove previous log handlers
